# import os,sys
# os.chdir(sys.path[0])
from query_toolkits.extractor import Extractor

et = Extractor()
extract_time = et.extract_time
extract_number = et.extract_number
extract_requirement = et.extract_requirement
